@@ -25,7 +25,7 @@ class MoveCommand : public QUndoCommand, public IKEBCommand
 public:
     MoveCommand(KBookmarkModel *model, const QString &from, const QString &to, const QString &name = QString(), QUndoCommand *parent = nullptr);
     QString finalAddress() const;
-    virtual ~MoveCommand()
+    ~MoveCommand() override
     {
     }
     void redo() override;
